@@ -1,8 +1,8 @@
 import gzip
-import plugin_pb2
 import json
 import threading
 from google.protobuf import json_format
+from robomotion import plugin_pb2
 from robomotion.struct_pb2 import Struct
 from robomotion.plugin_pb2_grpc import RuntimeHelperStub
 
